@@ -1,14 +1,14 @@
+from typing import List, Callable, Union, Tuple, Dict, Any, Optional, Type
 import datetime
 import decimal
-import re
 import itertools
-from typing import List, Callable, Union, Tuple, Dict, Any, Optional
+import re
+import inspect
 
 from django.conf import settings
 from django.core.exceptions import ValidationError as DjangoValidationError
-from django.db.models import IntegerChoices
-from django.db.models import TextChoices
 from django.db.models.fields import CharField as DjangoCharField
+from django.db.models.enums import Choices
 from django.db.models.functions import Concat
 from django.db.models.query_utils import Q
 from django.utils import timezone
@@ -18,12 +18,13 @@ from rest_framework.exceptions import ValidationError
 from rest_framework.fields import get_error_detail
 
 from drf_query_filter import mixins
-from drf_query_filter.utils import ConnectorType
+from drf_query_filter.utils import ConnectorType, choices2help_text
 
 
 class Empty:
     """ Dummy class just to represent a True None value """
-    pass
+    def __str__(self):
+        return '<Empty>'
 
 
 class Node:
@@ -62,7 +63,8 @@ class Node:
             return '(%(connector)s: [%(children)s])' % \
                    {
                        'connector': self.connector.value,
-                       'children':  ', '.join([repr(child) for child in self.children]),
+                       'children':  ', '.join(
+                           [repr(child) for child in self.children]),
                    }
         return '`EMPTY NODE`'
 
@@ -86,7 +88,8 @@ class Node:
                 query |= _query
         return query, annotate
 
-    def filter(self, queryset, data, raise_exceptions=False) -> Tuple[Any, Dict]:
+    def filter(self, queryset, data,
+               raise_exceptions=False) -> Tuple[Any, Dict]:
         # This gets the query and annotate of all children and itself
         query, annotate = self.get_filter(data)
 
@@ -140,13 +143,15 @@ class Field(Node):
         :param connector: Type of connector in the target fields.
         """
         self.field_name: str = field_name
-        assert self.field_name, '%s.field_name cannot be empty.' % self.__class__.__name__
+        assert self.field_name, (
+            '%s.field_name cannot be empty.' % self.__class__.__name__)
 
         self.target_fields = target_fields or self.field_name
 
         assert isinstance(self.target_fields, (str, list, tuple)), (
-                'given target_fields is a `%s`, expected a str or a list/tuple.' %
-                type(self.target_fields)
+            'given target_fields is a `%s`,'
+            'expected a str or a list/tuple.' %
+            type(self.target_fields)
         )
 
         if isinstance(self.target_fields, str):
@@ -154,7 +159,8 @@ class Field(Node):
 
         self.validators: List[Callable] = validators
 
-        self._raw_value: Any = Empty()  # value got from the query param request
+        # value got from the query param request
+        self._raw_value: Any = Empty()
         self._value: Any = self._raw_value  # transformed value
         self.no_value: bool = True  # Flag to check if this
         self._errors: List = []  # the list of errors we got
@@ -182,13 +188,15 @@ class Field(Node):
                    {
                        'connector':  self.connector.value,
                        'field_name': self.field_name,
-                       'children':   ', '.join([repr(child) for child in self.children]),
+                       'children':   ', '.join(
+                           [repr(child) for child in self.children]),
                    }
         return '%(field_name)s' % {'field_name': self.field_name}
 
     @property
     def value(self) -> Any:
-        assert not isinstance(self._value, Empty), 'you must call is_valid first'
+        assert not isinstance(self._value, Empty), (
+            'you must call is_valid first')
         return self._value
 
     @property
@@ -212,7 +220,8 @@ class Field(Node):
         """ This runs the validators like the fields in rest_framework """
         if self.validators:
             for validator in self.validators:
-                # Run all the validators and gather all the errors raised by them
+                # Run all the validators and gather all the errors raised by
+                #  them
                 try:
                     validator(value)
                 except ValidationError as exc:
@@ -337,8 +346,9 @@ class IntegerField(Field):
         try:
             return int(value)
         except (TypeError, ValueError):
-            raise ValidationError(self.error_messages['invalid'] % {'value': value},
-                                  code='invalid')
+            raise ValidationError(
+                self.error_messages['invalid'] % {'value': value},
+                code='invalid')
 
     def get_coreschema_field(self):
         return coreschema.Integer()
@@ -353,8 +363,8 @@ class IntegerField(Field):
 class RangeIntegerField(mixins.Range,
                         IntegerField):
     """
-    Accepts two integer values in the string and generate a query with greater than and/or
-    lesser than in the target fields.
+    Accepts two integer values in the string and generate a
+    query with greater than and/or lesser than in the target fields.
     """
     pass
 
@@ -372,8 +382,9 @@ class FloatField(Field):
         try:
             return float(value)
         except (TypeError, ValueError):
-            raise ValidationError(self.error_messages['invalid'] % {'value': value},
-                                  code='invalid')
+            raise ValidationError(
+                self.error_messages['invalid'] % {'value': value},
+                code='invalid')
 
     def get_coreschema_field(self):
         return coreschema.Number()
@@ -388,8 +399,8 @@ class FloatField(Field):
 class RangeFloatField(mixins.Range,
                       FloatField):
     """
-    Accepts two float values in the string and generate a query with greater than and/or
-    lesser than in the target fields.
+    Accepts two float values in the string and generate a query with
+    greater than and/or lesser than in the target fields.
     """
     pass
 
@@ -406,16 +417,19 @@ class DecimalField(Field):
         try:
             value = decimal.Decimal(value)
         except (decimal.InvalidOperation, TypeError, ValueError):
-            raise ValidationError(self.error_messages['invalid'] % {'value': value},
-                                  code='invalid')
+            raise ValidationError(
+                self.error_messages['invalid'] % {'value': value},
+                code='invalid')
 
         if value.is_nan():
-            raise ValidationError(self.error_messages['invalid'] % {'value': value},
-                                  code='invalid')
+            raise ValidationError(
+                self.error_messages['invalid'] % {'value': value},
+                code='invalid')
 
         if value in (decimal.Decimal('Inf'), decimal.Decimal('-Inf')):
-            raise ValidationError(self.error_messages['invalid'] % {'value': value},
-                                  code='invalid')
+            raise ValidationError(
+                self.error_messages['invalid'] % {'value': value},
+                code='invalid')
 
         return value
 
@@ -460,7 +474,9 @@ class DateTimeField(Field):
         try:
             date = datetime.datetime.strptime(value, self.date_format)
             _timezone = default_timezone()
-            if _timezone and (date.tzinfo is None or date.tzinfo.utcoffset(date) is None):
+            if _timezone and (
+                    date.tzinfo is None
+                    or date.tzinfo.utcoffset(date) is None):
                 return timezone.make_aware(date, _timezone)
             return date
         except ValueError:
@@ -502,7 +518,8 @@ class DateField(DateTimeField):
             return date
         except ValueError:
             raise ValidationError(self.error_messages['wrong_format'] % {
-                'value': value, 'date_format': self.date_format}, code='wrong_format')
+                'value': value, 'date_format': self.date_format},
+                code='wrong_format')
 
     def get_coreschema_field(self):
         return coreschema.String(
@@ -532,11 +549,12 @@ class ChoicesField(Field):
     """
 
     default_choices = []
-    default_validate_message = 'Value `%(value)s` is not a valid option, Options are: ' \
-                               '%(choices)s '
+    default_validate_message = 'Value `%(value)s` is not a valid option,' \
+                               'Options are: %(choices)s '
 
     def __init__(self, *args,
                  choices: Union[
+                     Type[Choices],
                      List[Tuple[str, str]],
                      List[str],
                  ] = None,
@@ -549,11 +567,12 @@ class ChoicesField(Field):
         super().__init__(*args, **kwargs)
 
     def sanitize_choices(self, choices) -> List[Tuple[str, str]]:
-        """
-        makes sure that choices it's a tuple.
-        """
+        """Makes sure that choices it's a valid type."""
+        if inspect.isclass(choices) and issubclass(choices, Choices):
+            choices = choices.choices
         return [
-            (str(choice[0]), str(choice[1])) if isinstance(choice, tuple) else (choice, Empty())
+            (str(choice[0]), str(choice[1]))
+            if isinstance(choice, tuple) else (choice, Empty())
             for choice in choices
         ]
 
@@ -566,11 +585,14 @@ class ChoicesField(Field):
             }, code='not_in_choices')
         return value
 
+    def get_description(self) -> str:
+        return '%s%s' % (
+            self.description + '  \n' if self.description else '',
+            choices2help_text(self.choices)
+        )
+
     def get_choices_for_schema(self):
-        return [
-            choice[0] if isinstance(choice[1], Empty) else '`%s`: %s' % choice
-            for choice in self.choices
-        ]
+        return [choice[0] for choice in self.choices]
 
     def get_coreschema_field(self):
         return coreschema.Enum(self.get_choices_for_schema())
@@ -590,12 +612,16 @@ class BooleanField(ChoicesField):
     def __init__(self, *args, invert=False, **kwargs):
         # ignore the kwargs of choices
         kwargs['choices'] = [
-            'true', 'True', 't', 'T', '1',
-            'false', 'False', 'f', 'F', '0'
+            ('true', True), ('True', True),
+            ('t', True), ('T', True),
+            ('1', True),
+            ('false', False), ('False', False),
+            ('f', False), ('F', False),
+            ('0', False),
         ]
         self.invert = invert
-        kwargs['validate_message'] = 'Value `%(value)s` is not a valid boolean. Options '\
-                                     'are: %(choices)s '
+        kwargs['validate_message'] = 'Value `%(value)s` is not a valid ' \
+            'boolean. Options are: %(choices)s '
         super().__init__(*args, **kwargs)
 
     def validate(self, value):
@@ -641,7 +667,9 @@ class ConcatField(Field):
 
     def get_query(self):
         query = Q(**{
-            '%s%s' % (self.target_field_name, self.get_lookup()): self.get_value_query()
+            '%s%s' % (
+                self.target_field_name, self.get_lookup()
+            ): self.get_value_query()
         })
         return query
 
